// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef PACKAGE_VERSION_H
#define PACKAGE_VERSION_H

#define PACKAGE_VERSION_STRING "6.17.0"
#define PACKAGE_VERSION_MAJOR 6
#define PACKAGE_VERSION_MINOR 17
#define PACKAGE_VERSION_PATCH 0
#define PACKAGE_VERSION ((6<<16)|(17<<8)|(0))

#endif
